<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// 0
'0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-dev',
'0_langue' => '&#268;e&#353;tina [cs]',
'0_liste' => 'spip-cs@rezo.net',
'0_mainteneur' => 'otto@pacholik.cz',

// A
'access_interface_graphique' => 'Zp&#283;t do kompletn&iacute;ho grafick&eacute;ho rozhran&iacute;',
'access_mode_texte' => 'Zobrazit jednoduch&eacute; textov&eacute; rozhran&iacute;',
'admin_debug' => 'lad&#283;n&iacute;',
'admin_modifier_article' => 'Zm&#283;nit &#269;l&aacute;nek',
'admin_modifier_auteur' => 'Zm&#283;nit autora',
'admin_modifier_breve' => 'Zm&#283;nit tuto zpr&aacute;vu',
'admin_modifier_mot' => 'Zm&#283;nit kl&iacute;&#269;ov&eacute; slovo',
'admin_modifier_rubrique' => 'Zm&#283;nit sekci',
'admin_recalculer' => 'Obnovit str&aacute;nku',
'afficher_trad' => 'vyv&#283;sit p&#345;eklady',
'alerte_maj_impossible' => '<b>Varov&aacute;n&iacute;!</b> Aktualizace datab&aacute;ze SQL na verzi @version@ se nezda&#345;ila. Je mo&#382;n&eacute;, &#382;e je to kv&#367;li probl&eacute;m&#367;m s p&#345;&iacute;stupov&yacute;mi pr&aacute;vy k datab&aacute;zi. Kontaktujte sv&eacute;ho poskytovatele p&#345;ipojen&iacute; k internetu (ISP).',
'alerte_modif_info_concourante' => 'VAROV&Aacute;N&Iacute;: Tato informace byla zm&#283;n&#283;na na jin&eacute;m m&iacute;st&#283;. Sou&#269;asn&aacute; hodnota je&nbsp;:',
'analyse_xml' => 'XML parsov&aacute;n&iacute;',
'annuler' => 'Storno',
'antispam_champ_vide' => 'Tuto polo&#382;ku nechte pros&iacute;m pr&aacute;zdnou:',
'articles_recents' => 'Ned&aacute;vn&eacute; &#269;l&aacute;nky',
'avis_archive_incorrect' => 'soubor nen&iacute; platn&yacute;m SPIP archivem',
'avis_archive_invalide' => 'neplatn&yacute; soubor arch&iacute;vu',
'avis_attention' => 'POZOR!',
'avis_champ_incorrect_type_objet' => 'Naplatn&yacute; n&aacute;zev pole @name@ objektu typu @type@',
'avis_colonne_inexistante' => 'Sloupec @col@ neexistuje',
'avis_echec_syndication_01' => 'Vytvo&#345;en&iacute; dat selhalo: Bu&#271; nelze &#269;&iacute;st z vybran&eacute;ho z&aacute;kladn&iacute;ho syst&eacute;mu (backend) nebo na n&#283;m nen&iacute; &#382;&aacute;dn&yacute; &#269;l&aacute;nek.',
'avis_echec_syndication_02' => 'Selhalo zpracov&aacute;n&iacute; dat: Nelze komunikovat se z&aacute;kladn&iacute;m syst&eacute;mem (backend) t&#283;chto str&aacute;nek.',
'avis_erreur' => 'Chyba: viz n&iacute;&#382;e;',
'avis_erreur_connexion' => 'Chyba p&#345;i spojen&iacute;',
'avis_erreur_cookie' => 'Probl&eacute;my se su&#353;enkou :-) (cookie)',
'avis_erreur_fonction_contexte' => 'Program&aacute;torsk&aacute; chyba. Funkce by nem&#283;la b&yacute;t v tomto kontextu vol&aacute;na.',
'avis_erreur_mysql' => 'Chyba SQL',
'avis_erreur_sauvegarde' => 'Chyba v z&aacute;lohov&aacute;n&iacute; (@type@ @id_objet@)!',
'avis_erreur_visiteur' => 'Probl&eacute;m p&#345;i vstupu do priv&aacute;tn&iacute; z&oacute;ny',

// B
'barre_a_accent_grave' => 'Zadejte velk&eacute; A s obr&aacute;cenou &#269;&aacute;rkou (`)',
'barre_aide' => 'Vzhled str&aacute;nek (layout) dola&#271;te pomoc&iacute; typografick&yacute;ch zkratek',
'barre_e_accent_aigu' => 'Zadejte p&iacute;smeno &Eacute;',
'barre_eo' => 'Zadejte p&iacute;smeno oe',
'barre_eo_maj' => 'Zadejte p&iacute;smeno EO',
'barre_euro' => 'Zadejte symbol &euro;',
'barre_gras' => 'Zadejte {{tu&#269;n&eacute; p&iacute;smo}}',
'barre_guillemets' => 'Um&iacute;st&#283;te znaky do dvojit&yacute;ch uvozovek (")',
'barre_guillemets_simples' => 'Um&iacute;st&#283;te znaky do jednoduch&yacute;ch uvozovek (‘)',
'barre_intertitre' => 'Zm&#283;&#328;te na {{{podz&aacute;hlav&iacute;}}}',
'barre_italic' => 'Zadejte {kurz&iacute;vou}',
'barre_lien' => 'Zm&#283;nit na [hypertextov&yacute; odkaz->http://...]',
'barre_lien_input' => 'Zadejte c&iacute;l hypertextov&eacute;ho odkazu (adresu URL ve form&aacute;tu http://www.mysite.com nebo &#269;&iacute;slo &#269;l&aacute;nku na t&#283;chto str&aacute;nk&aacute;ch).',
'barre_note' => 'Zm&#283;nit na [[pozn&aacute;mku pod &#269;arou]]',
'barre_paragraphe' => 'Vytvo&#345;it odstavec',
'barre_quote' => '<quote>Citovat zpr&aacute;vu</quote>',
'bouton_ajouter_document' => 'P&#344;IDAT DOKUMENT',
'bouton_ajouter_image' => 'P&#344;IDAT OBR&Aacute;ZEK',
'bouton_ajouter_image_document' => 'P&#345;idat obr&aacute;zek nebo dokument',
'bouton_changer' => 'Zm&#283;nit',
'bouton_chercher' => 'Naj&iacute;t',
'bouton_choisir' => 'Vybrat',
'bouton_download' => 'Download',
'bouton_enregistrer' => 'Ulo&#382;it',
'bouton_radio_desactiver_messagerie_interne' => 'Vypnout intern&iacute; hl&aacute;&#353;en&iacute;',
'bouton_radio_envoi_annonces' => 'Zaslat editorsk&aacute; ozn&aacute;men&iacute;',
'bouton_radio_non_envoi_annonces' => 'Nezas&iacute;lat &#382;&aacute;dn&aacute; ozn&aacute;men&iacute;',
'bouton_radio_non_envoi_liste_nouveautes' => 'Nezas&iacute;lat seznam nejnov&#283;j&#353;&iacute;ch zpr&aacute;v',
'bouton_recharger_page' => 'znovu na&#269;&iacute;st tuto str&aacute;nku',
'bouton_telecharger' => 'Odeslat',
'bouton_valider' => 'Odeslat',

// C
'cal_apresmidi' => 'odpoledne',
'cal_jour_entier' => 'cel&yacute; den',
'cal_matin' => 'dopoledne',
'cal_par_jour' => 'zobrazen&iacute; jednotliv&yacute;ch dn&#367;',
'cal_par_mois' => 'zobrazen&iacute; cel&eacute;ho m&#283;s&iacute;ce',
'cal_par_semaine' => 'zobrazen&iacute; cel&yacute;ch t&yacute;dn&#367;',
'choix_couleur_interface' => 'barva',
'choix_interface' => 'volba rozhran&iacute;',
'colonne' => 'Sloupec',
'confirm_changer_statut' => 'Je nutn&eacute; potvrzen&iacute; akce: Po&#382;&aacute;dali jste o zm&#283;nu stavu &#269;l&aacute;nku. Chcete pokra&#269;ovat?',
'correcte' => 'spr&aacute;vn&#283;',

// D
'date_aujourdhui' => 'dnes',
'date_avant_jc' => 'p&#345;. n. l.',
'date_dans' => 'b&#283;hem @delai@',
'date_de_mois_1' => '@j@ ledna',
'date_de_mois_10' => '@j@ &#345;&iacute;jna',
'date_de_mois_11' => '@j@ listopadu',
'date_de_mois_12' => '@j@ prosince',
'date_de_mois_2' => '@j@ &uacute;nora',
'date_de_mois_3' => '@j@ b&#345;ezna',
'date_de_mois_4' => '@j@ dubna',
'date_de_mois_5' => '@j@ kv&#283;tna',
'date_de_mois_6' => '@j@ &#269;ervna',
'date_de_mois_7' => '@j@ &#269;ervence',
'date_de_mois_8' => '@j@ srpna',
'date_de_mois_9' => '@j@ z&aacute;&#345;&iacute;',
'date_demain' => 'z&iacute;tra',
'date_fmt_heures_minutes' => '@h@h@m@min',
'date_fmt_jour_heure' => '@jour@ a @heure@',
'date_fmt_jour_mois' => '@jourmois@',
'date_fmt_jour_mois_annee' => '@jourmois@ @annee@',
'date_fmt_mois_annee' => '@nommois@ @annee@',
'date_fmt_nomjour_date' => '@date@ @nomjour@',
'date_heures' => 'hodin',
'date_hier' => 'v&#269;era',
'date_il_y_a' => 'p&#345;ed @delai@',
'date_jnum1' => '1.',
'date_jnum10' => '10.',
'date_jnum11' => '11.',
'date_jnum12' => '12.',
'date_jnum13' => '13.',
'date_jnum14' => '14.',
'date_jnum15' => '15.',
'date_jnum16' => '16.',
'date_jnum17' => '17.',
'date_jnum18' => '18.',
'date_jnum19' => '19.',
'date_jnum2' => '2.',
'date_jnum20' => '20.',
'date_jnum21' => '21.',
'date_jnum22' => '22.',
'date_jnum23' => '23.',
'date_jnum24' => '24.',
'date_jnum25' => '25.',
'date_jnum26' => '26.',
'date_jnum27' => '27.',
'date_jnum28' => '28.',
'date_jnum29' => '29.',
'date_jnum3' => '3.',
'date_jnum30' => '30.',
'date_jnum31' => '31.',
'date_jnum4' => '4.',
'date_jnum5' => '5.',
'date_jnum6' => '6.',
'date_jnum7' => '7.',
'date_jnum8' => '8.',
'date_jnum9' => '9.',
'date_jour_1' => 'ned&#283;le',
'date_jour_1_abbr' => 'Ne.',
'date_jour_1_initiale' => 'N.',
'date_jour_2' => 'pond&#283;l&iacute;',
'date_jour_2_abbr' => 'Po.',
'date_jour_2_initiale' => 'P.',
'date_jour_3' => '&uacute;ter&yacute;',
'date_jour_3_abbr' => '&Uacute;t.',
'date_jour_3_initiale' => '&Uacute;.',
'date_jour_4' => 'st&#345;eda',
'date_jour_4_abbr' => 'St.',
'date_jour_4_initiale' => 'S.',
'date_jour_5' => '&#269;tvrtek',
'date_jour_5_abbr' => '&#268;t.',
'date_jour_5_initiale' => '&#268;.',
'date_jour_6' => 'p&aacute;tek',
'date_jour_6_abbr' => 'P&aacute;.',
'date_jour_6_initiale' => 'P.',
'date_jour_7' => 'sobota',
'date_jour_7_abbr' => 'So.',
'date_jour_7_initiale' => 'S.',
'date_jours' => 'dn&#367;',
'date_minutes' => 'minut',
'date_mois' => 'm&#283;s&iacute;c&#367;',
'date_mois_1' => 'Leden',
'date_mois_10' => '&#344;&iacute;jen',
'date_mois_11' => 'Listopad',
'date_mois_12' => 'Prosinec',
'date_mois_2' => '&Uacute;nor',
'date_mois_3' => 'B&#345;ezen',
'date_mois_4' => 'Duben',
'date_mois_5' => 'Kv&#283;ten',
'date_mois_6' => '&#268;erven',
'date_mois_7' => '&#268;ervenec',
'date_mois_8' => 'Srpen',
'date_mois_9' => 'Z&aacute;&#345;&iacute;',
'date_saison_1' => 'zima',
'date_saison_2' => 'jaro',
'date_saison_3' => 'l&eacute;to',
'date_saison_4' => 'podzim',
'date_secondes' => 'seconds', # NEW
'date_semaines' => 't&yacute;dn&#367;',
'date_un_mois' => 'month', # NEW
'date_une_heure' => 'hour', # NEW
'date_une_minute' => 'minute', # NEW
'date_une_seconde' => 'second', # NEW
'date_une_semaine' => 'week', # NEW
'dirs_commencer' => 'pro vlastn&iacute; zah&aacute;jen&iacute; instalace',
'dirs_preliminaire' => 'P&#345;edb&#283;&#382;n&aacute; akce: <b>Nastaven&iacute; p&#345;&iacute;stupov&yacute;ch pr&aacute;v</b>',
'dirs_probleme_droits' => 'Probl&eacute;m s p&#345;&iacute;stupov&yacute;mi pr&aacute;vy',
'dirs_repertoires_absents' => '<p><b>Nebyl nalezen adres&aacute;&#345;, resp. adres&aacute;&#345;e:</b></p> <ul>@bad_dirs@.</ul> 
  <p>M&#367;&#382;e to b&yacute;t kv&#367;li nespr&aacute;vn&eacute;mu zad&aacute;n&iacute; velk&yacute;ch a mal&yacute;ch p&iacute;smen.
  Zkontrolujte, zda mal&aacute; a velk&aacute; p&iacute;smena uveden&eacute;ho adres&aacute;&#345;e, resp. adres&aacute;&#345;&#367; souhlas&iacute; s t&iacute;m,
  co je uvedeno v&yacute;&#353;e. Pokud ne, p&#345;ejmenujte adres&aacute;&#345;e pomoc&iacute; klienta programu FTP. T&iacute;m chybu oprav&iacute;te.</p>
  <p>Pot&eacute; m&#367;&#382;ete',
'dirs_repertoires_suivants' => '<p><b>K n&aacute;sleduj&iacute;c&iacute;mu adres&aacute;&#345;i, resp. adres&aacute;&#345;&#367;m chyb&iacute; pr&aacute;vo z&aacute;pisu:</b></p><ul>@bad_dirs@.</ul>
<p>Zm&#283;&#328;te tato pr&aacute;va pomoc&iacute; klienta FTP a nastavte pr&aacute;va p&#345;&iacute;stupu jednotliv&yacute;ch adres&aacute;&#345;&#367;
  Podrobn&yacute; popis je v n&aacute;vodu k instalaci.</p>
  <p>Pot&eacute; m&#367;&#382;ete ',
'double_occurrence' => 'Dv&#283; instance', # MODIF

// E
'en_cours' => 'prob&iacute;h&aacute; zpracov&aacute;n&iacute;',
'entree_dimensions' => 'Velikost:',
'entree_titre_document' => 'N&aacute;zev dokumentu:',
'entree_titre_image' => 'N&aacute;zev obr&aacute;zku:',
'envoi_via_le_site' => 'Odeslat pomoc&iacute; webu',
'erreur' => 'Error', # NEW
'erreur_balise_non_fermee' => 'last tag not closed:', # NEW
'erreur_texte' => 'error(s)', # NEW
'etape' => 'Stage', # NEW

// F
'fichier_introuvable' => 'Nalezen nov&yacute; soubor: @fichier@',
'form_auteur_confirmation' => 'Please confirm your email address', # NEW
'form_auteur_email_modifie' => 'Your email address has been changed.', # NEW
'form_auteur_envoi_mail_confirmation' => 'A confirmation email has been sent to @email@. You need to visit the URL mentioned in this message in order to validate your email address.', # NEW
'form_auteur_mail_confirmation' => 'Hello,

You have asked to change your email address.
To confirm your new address, you need to connect to
the address below. (Otherwise your request will be ignored.):

    @url@
', # NEW
'form_deja_inscrit' => 'U&#382; jste zaregistrov&aacute;ni.',
'form_email_non_valide' => 'Neplatn&aacute; elektronick&aacute; adresa.',
'form_forum_access_refuse' => 'K tomuto webu ji&#382; nem&aacute;te p&#345;&iacute;stup.',
'form_forum_bonjour' => 'Dobr&yacute; den @nom@,',
'form_forum_email_deja_enregistre' => 'Tato elektronick&aacute; adresa je ji&#382; zaregistrov&aacute;na. M&#367;&#382;ete tedy pou&#382;&iacute;vat sv&eacute; obvykl&eacute; heslo.',
'form_forum_identifiant_mail' => 'Nov&eacute; identifika&#269;n&iacute; &uacute;daje v&aacute;m byly odesl&aacute;ny elektronickou po&#353;tou.',
'form_forum_identifiants' => 'Osobn&iacute; identifika&#269;n&iacute; &uacute;daje',
'form_forum_indiquer_nom_email' => 'Zadejte jm&eacute;no a elektronickou adresu. Osobn&iacute; identifika&#269;n&iacute; &uacute;daje obdr&#382;&iacute;te v brzk&eacute; dob&#283; elektronickou po&#353;tou.',
'form_forum_login' => 'Login:',
'form_forum_message_auto' => '(toto je automatick&aacute; zpr&aacute;va)',
'form_forum_pass' => 'Heslo:',
'form_forum_probleme_mail' => 'Probl&eacute;my s elektronickou po&#353;tou: Odesl&aacute;n&iacute; identifika&#269;n&iacute;ch &uacute;daj&#367; se nezda&#345;ilo.',
'form_forum_voici1' => 'Zde jsou identifika&#269;n&iacute; &uacute;daje umo&#382;&#328;uj&iacute;c&iacute; &uacute;&#269;ast na aktivit&aacute;ch tohoto webu
"@nom_site_spip@" (@adresse_site@):',
'form_forum_voici2' => 'Zde jsou identifika&#269;n&iacute; &uacute;daje, kter&eacute; v&aacute;m umo&#382;n&iacute; publikovat &#269;l&aacute;nky
na webu "@nom_site_spip@" (@adresse_login@):',
'form_indiquer_email' => 'Zadejte sv&#367;j e-mail.',
'form_indiquer_nom' => 'Zadejte sv&eacute; jm&eacute;no.',
'form_indiquer_nom_site' => 'Zadejte n&aacute;zev sv&eacute;ho webu.',
'form_pet_adresse_site' => 'Zadejte adresu URL sv&eacute;ho webu',
'form_pet_aucune_signature' => 'Tomuto k&oacute;du neodpov&iacute;d&aacute; &#382;&aacute;dn&yacute; podpis...',
'form_pet_confirmation' => 'Potvr&#271;te sv&#367;j podpis:',
'form_pet_deja_enregistre' => 'Tento web je ji&#382; zaregistrov&aacute;n',
'form_pet_deja_signe' => 'Tento text jste ji&#382; podepsali.',
'form_pet_envoi_mail_confirmation' => 'Byla v&aacute;m zasl&aacute;na elektronick&aacute; zpr&aacute;va s potvrzen&iacute;m. Platnost podpisu ov&#283;&#345;&iacute;te na adrese URL, kter&aacute; je v t&eacute;to zpr&aacute;v&#283; uvedena.', # MODIF
'form_pet_mail_confirmation' => 'Dobr&yacute; den,

Rozhodli jste se podepsat petici:
@titre@.

Uvedli jste n&aacute;sleduj&iacute;c&iacute; &uacute;daje:
    Jm&eacute;no: @nom_email@
    Web: @nom_site@ - @url_site@
    @message@

D&#366;LE&#381;IT&Eacute; UPOZORN&#282;N&Iacute;...
Platnost sv&eacute;ho podpisu potvrd&iacute;te p&#345;echodem
na n&iacute;&#382;e uvedenou adresu (jinak bude v&aacute;&#353; po&#382;adavek
zam&iacute;tnut):

    @url@


D&#283;kujeme v&aacute;m za &uacute;&#269;ast
',
'form_pet_message_commentaire' => 'Chcete n&aacute;m n&#283;co sd&#283;lit nebo m&aacute;te n&#283;jak&eacute; p&#345;ipom&iacute;nky?',
'form_pet_nom_site2' => 'N&aacute;zev va&#353;eho webu',
'form_pet_probleme_liens' => 'Please edit your message, taking out all hyperlinks.', # NEW
'form_pet_probleme_technique' => 'Z technick&yacute;ch d&#367;vod&#367; nelze moment&aacute;ln&#283; podepisovat.',
'form_pet_signature_pasprise' => 'V&aacute;&#353; podpis nebyl zohledn&#283;n.',
'form_pet_signature_validee' => 'V&aacute;&#353; podpis je platn&yacute;. D&#283;kujeme v&aacute;m!',
'form_pet_site_deja_enregistre' => 'Tento web je ji&#382; zaregistrov&aacute;n',
'form_pet_url_invalide' => 'Zadali jste neplatnou adresu URL.',
'form_pet_votre_email' => 'Nov&aacute; elektronick&aacute; adresa',
'form_pet_votre_nom' => 'Jm&eacute;no nebo p&#345;ezd&iacute;vka (alias)',
'form_pet_votre_site' => 'M&aacute;te-li web, m&#367;&#382;ete d&aacute;le zadat jeho adresu',
'form_prop_confirmer_envoi' => 'Potvr&#271;te odesl&aacute;n&iacute;',
'form_prop_description' => 'Popis/pozn&aacute;mka',
'form_prop_enregistre' => 'V&aacute;&#353; n&aacute;vrh byl zaregistrov&aacute;n. Po kontrole spr&aacute;vci tohoto webu bude zv&#283;&#345;ejn&#283;n online.',
'form_prop_envoyer' => 'Odeslat zpr&aacute;vu',
'form_prop_indiquer_email' => 'Zadejte platnou elektronickou adresu',
'form_prop_indiquer_nom_site' => 'Zadejte n&aacute;zev webu.',
'form_prop_indiquer_sujet' => 'Zadejte p&#345;edm&#283;t',
'form_prop_message_envoye' => 'Zpr&aacute;va byla odesl&aacute;na',
'form_prop_nom_site' => 'N&aacute;zev webu',
'form_prop_non_enregistre' => 'V&aacute;&#353; n&aacute;vrh byl zaznamen&aacute;n.',
'form_prop_sujet' => 'P&#345;edm&#283;t',
'form_prop_url_site' => 'Adresa URL webu',
'forum_acces_refuse' => 'K t&#283;mto diskusn&iacute;m skupin&aacute;m ji&#382; nem&aacute;te p&#345;&iacute;stup.',
'forum_attention_dix_caracteres' => '<b>Varov&aacute;n&iacute;!</b> Zpr&aacute;va mus&iacute; obsahovat minim&aacute;ln&#283; deset znak&#367;.',
'forum_attention_trois_caracteres' => '<b>Varov&aacute;n&iacute;!</b> N&aacute;zev mus&iacute; obsahovat minim&aacute;ln&#283; deset znak&#367;.',
'forum_attention_trop_caracteres' => '<b>Varov&aacute;n&iacute;&nbsp;!</b> va&#353;e zpr&aacute;va je p&#345;&iacute;li&#353; dlouh&aacute;(@compte@ znak&#367;)&nbsp;: aby j&iacute; bylo mo&#382;n&eacute; ulo&#382;it, nesm&iacute; obsahovat v&iacute;ce ne&#382;  @max@ znak&#367;.',
'forum_avez_selectionne' => 'Zvolili jste:',
'forum_cliquer_retour' => 'Pokra&#269;ujte klepnut&iacute;m <a href=\'@retour_forum@\'>na tento odkaz</a>.',
'forum_forum' => 'diskusn&iacute; skupina',
'forum_info_modere' => 'Tato diskusn&iacute; skupina je moderovan&aacute;: va&#353;e p&#345;&iacute;sp&#283;vky se zobraz&iacute; a&#382; po schv&aacute;len&iacute; spr&aacute;vcem tohoto webu.',
'forum_lien_hyper' => '<b>Hypertextov&yacute; odkaz</b> (voliteln&eacute;)',
'forum_message_definitif' => 'Z&aacute;v&#283;re&#269;n&aacute; zpr&aacute;va: odesl&aacute;no na web',
'forum_message_trop_long' => 'Zpr&aacute;va je p&#345;&iacute;li&#353; dlouh&aacute;. Maximum je 20.000 znak&#367;.',
'forum_ne_repondez_pas' => 'Neodpov&iacute;dejte na tuto zpr&aacute;vu. Odpov&#283;&#271; zve&#345;ejn&#283;te v r&aacute;mci skupiny na adrese:',
'forum_non_inscrit' => 'Bu&#271; nejste zaregistrov&aacute;ni nebo jste zadali nespr&aacute;vnou adresu &#269;i heslo.',
'forum_page_url' => '(T&yacute;k&aacute;-li se zpr&aacute;va &#269;l&aacute;nku zve&#345;ejn&#283;n&eacute;ho na webu nebo str&aacute;nky s dopl&#328;uj&iacute;c&iacute;mi informacemi, zadejte d&aacute;le n&aacute;zev str&aacute;nky a jej&iacute; adresu).',
'forum_par_auteur' => 'Autor: @auteur@',
'forum_poste_par' => 'Zpr&aacute;va od posted@parauteur@ na z&aacute;klad&#283; va&#353;eho &#269;l&aacute;nku.', # MODIF
'forum_probleme_database' => 'Kv&#367;li probl&eacute;m&#367;m s datab&aacute;z&iacute; nebylo mo&#382;n&eacute; va&#353;i zpr&aacute;vu zaznamenat.',
'forum_qui_etes_vous' => '<b>Kdo jste?</b> (voliteln&eacute;)',
'forum_texte' => 'Text zpr&aacute;vy:',
'forum_titre' => 'P&#345;edm&#283;t:',
'forum_titre_erreur' => 'Chyba...',
'forum_url' => 'Adresa URL:',
'forum_valider' => 'Potvrdit v&yacute;b&#283;r',
'forum_voir_avant' => 'P&#345;ed odesl&aacute;n&iacute;m zpr&aacute;vu zobrazit',
'forum_votre_email' => 'V&aacute;&#353; e-mail:',
'forum_votre_nom' => 'Va&#353;e jm&eacute;no (resp. p&#345;ezd&iacute;vka):',
'forum_vous_enregistrer' => 'T&eacute;to diskusn&iacute; skupiny se m&#367;&#382;ete &uacute;&#269;astnit
  a&#382; po zaregistrov&aacute;n&iacute;. D&#283;kujeme v&aacute;m
  za zad&aacute;n&iacute; identifika&#269;n&iacute;ch &uacute;daj&#367;.
  Nejste-li doposud zaregistrov&aacute;ni, mus&iacute;te ',
'forum_vous_inscrire' => 'tak u&#269;init nyn&iacute;.',

// I
'ical_texte_rss_articles' => 'Adresa souboru na serveru (backend) &#269;l&aacute;nk&#367; na webu je:',
'ical_texte_rss_articles2' => 'M&#367;&#382;ete z&iacute;skat i serverov&eacute; soubory k &#269;l&aacute;nk&#367;m z jednotliv&yacute;ch sekc&iacute; webu:',
'ical_texte_rss_breves' => 'D&aacute;le existuje soubor obsahuj&iacute;c&iacute; novinky z webu. Zad&aacute;n&iacute;m &#269;&iacute;sla sekce z&iacute;sk&aacute;te pouze novinky t&yacute;kaj&iacute;c&iacute; se dan&eacute; sekce.',
'icone_a_suivre' => 'Hlavn&iacute; nab&iacute;dka',
'icone_admin_site' => 'Spr&aacute;va webu',
'icone_agenda' => 'Kalend&aacute;&#345;',
'icone_aide_ligne' => 'N&aacute;pov&#283;da',
'icone_articles' => '&#268;l&aacute;nky',
'icone_auteurs' => 'Auto&#345;i',
'icone_breves' => 'Novinky',
'icone_brouteur' => 'Rychl&eacute; proch&aacute;zen&iacute;',
'icone_configuration_site' => 'Nastaven&iacute;',
'icone_configurer_site' => 'Nastavte sv&#367;j web',
'icone_creer_nouvel_auteur' => 'Vytvo&#345;it nov&eacute;ho autora',
'icone_creer_rubrique' => 'Vytvo&#345;it sekci',
'icone_creer_sous_rubrique' => 'Vytvo&#345;it podsekci',
'icone_deconnecter' => 'Odhl&aacute;sit',
'icone_discussions' => 'Diskuse',
'icone_doc_rubrique' => 'Dokumenty v p&#345;&iacute;loze',
'icone_ecrire_article' => 'Napsat nov&yacute; &#269;l&aacute;nek',
'icone_edition_site' => 'Editovat web',
'icone_forum_administrateur' => 'Diskusn&iacute; skupina spr&aacute;vc&#367;',
'icone_forum_suivi' => 'Navazuj&iacute;c&iacute; zpr&aacute;vy diskusn&iacute; skupiny',
'icone_gestion_langues' => 'Spr&aacute;va jazyk&#367;',
'icone_informations_personnelles' => 'Osobn&iacute; &uacute;daje',
'icone_interface_complet' => '&Uacute;pln&eacute; rozhran&iacute;',
'icone_interface_simple' => 'Jednoduch&eacute; rozhran&iacute;',
'icone_maintenance_site' => '&Uacute;dr&#382;ba webu',
'icone_messagerie_personnelle' => 'Osobn&iacute; zpr&aacute;vy',
'icone_mots_cles' => 'Kl&iacute;&#269;ov&aacute; slova',
'icone_nouvelle_breve' => 'Napsat novinku',
'icone_repartition_actuelle' => 'Zobrazit aktu&aacute;ln&iacute; rozd&#283;len&iacute;',
'icone_repartition_debut' => 'Zobrazit rozd&#283;len&iacute; od po&#269;&aacute;tku',
'icone_repartition_visites' => 'Rozd&#283;len&iacute; n&aacute;v&#353;t&#283;v',
'icone_rubriques' => 'Sekce',
'icone_sauver_site' => 'Ulo&#382;en&iacute; webu',
'icone_site_entier' => 'V&#353;echny str&aacute;nky',
'icone_sites_references' => 'Str&aacute;nky na n&#283;&#382; existuj&iacute; odkazy',
'icone_statistiques' => 'Statistiky str&aacute;nek',
'icone_statistiques_visites' => 'Statistiky',
'icone_suivi_activite' => 'Sledov&aacute;n&iacute; aktivity webu',
'icone_suivi_actualite' => 'Statistiky str&aacute;nek',
'icone_suivi_forums' => 'Spr&aacute;va diskusn&iacute;ch skupin',
'icone_suivi_pettions' => 'Spr&aacute;va petic&iacute;',
'icone_suivi_revisions' => 'Revize &#269;l&aacute;nk&#367;',
'icone_supprimer_document' => 'Odstranit dokument',
'icone_supprimer_image' => 'Odstranit obr&aacute;zek',
'icone_supprimer_message' => 'Ostranit zpr&aacute;vu',
'icone_tous_articles' => 'V&#353;echny va&#353;e &#269;l&aacute;nky',
'icone_tous_auteur' => 'V&#353;ichni auto&#345;i',
'icone_valider_message' => 'Schv&aacute;lit zpr&aacute;vu',
'icone_visiter_site' => 'Zobrazit web',
'icone_voir_en_ligne' => 'Prohl&iacute;&#382;et online',
'image_tourner_180' => 'Oto&#269;it o 180&deg;',
'image_tourner_droite' => 'Oto&#269;it o 90&deg; doprava',
'image_tourner_gauche' => 'Oto&#269;it o 90&deg; doleva',
'img_indisponible' => 'Obr&aacute;zek nen&iacute; k dispozici',
'impossible' => 'nemo&#382;n&eacute;',
'info_a_suivre' => 'HLAVN&Iacute; NAB&Iacute;DKA"',
'info_a_valider' => '[ke schv&aacute;len&iacute;]',
'info_acces_interdit' => 'P&#345;&iacute;stup zak&aacute;z&aacute;n',
'info_acces_refuse' => 'P&#345;&iacute;stup odep&#345;en',
'info_action' => 'Akce: @action@',
'info_administrer_rubriques' => 'M&#367;&#382;ete prov&aacute;d&#283;t &uacute;dr&#382;bu t&eacute;to sekce a jej&iacute;ch podsekc&iacute;',
'info_adresse_non_indiquee' => 'Nezadali jste, kter&aacute; adresa se m&aacute; otestovat!',
'info_aide' => 'N&Aacute;POV&#282;DA:',
'info_ajouter_mot' => 'P&#345;idat kl&iacute;&#269;ov&eacute; slovo',
'info_annonce' => 'OZN&Aacute;MEN&Iacute;',
'info_annonces_generales' => 'Obecn&aacute; ozn&aacute;men&iacute;:',
'info_article_propose' => '&#268;l&aacute;nek byl odesl&aacute;n',
'info_article_publie' => '&#268;l&aacute;nek byl zve&#345;ejn&#283;n',
'info_article_redaction' => '&#268;l&aacute;nky ve zpracov&aacute;n&iacute;',
'info_article_refuse' => 'Odm&iacute;tnut&eacute; &#269;l&aacute;nky',
'info_article_supprime' => 'Odstran&#283;n&eacute; &#269;l&aacute;nky',
'info_articles' => '&#268;l&aacute;nky',
'info_articles_a_valider' => '&#268;l&aacute;nky ke schv&aacute;len&iacute;',
'info_articles_nb' => '@nb@ articles', # NEW
'info_articles_proposes' => 'P&#345;edlo&#382;en&eacute; &#269;l&aacute;nky',
'info_articles_un' => '1 article', # NEW
'info_auteurs_nombre' => 'Autor &#269;i auto&#345;i:',
'info_authentification_ftp' => 'Autentifikace (pomoc&iacute; FTP).',
'info_bloquer_lien' => 'zablokovat tento odkaz',
'info_breves_02' => 'Novinky',
'info_breves_2' => 'novinky',
'info_breves_nb' => '@nb@ news items', # NEW
'info_breves_un' => '1 news item', # NEW
'info_breves_valider' => 'Novinky ke schv&aacute;len&iacute;',
'info_connexion_refusee' => 'Spojen&iacute; bylo odep&#345;eno',
'info_contact_developpeur' => 'Kontaktujte v&yacute;voj&aacute;&#345;e.',
'info_contenance' => 'Tyto str&aacute;nky obsahuj&iacute;:',
'info_contribution' => 'p&#345;&iacute;sp&#283;vky do diskusn&iacute; skupiny',
'info_copyright' => '@spip@ je freeware distribuovan&yacute; @lien_gpl@.',
'info_copyright_doc' => 'Bli&#382;&#353;&iacute; informace viz <a href="@spipnet@">http://www.spip.net/en</a>.', # MODIF
'info_copyright_gpl' => 'v r&aacute;mci licence GPL',
'info_cours_edition' => 'Va&#353;e rozpracovan&eacute; &#269;l&aacute;nky',
'info_creer_repertoire' => 'Vytvo&#345;te soubor nebo adres&aacute;&#345; s n&aacute;zvem:',
'info_creer_repertoire_2' => 'v podadres&aacute;&#345;i <b>@repertoire@</b>. Potom',
'info_creer_vignette' => 'automatick&eacute; vytvo&#345;en&iacute; n&aacute;hledu',
'info_deplier' => 'Rozbalit',
'info_descriptif_nombre' => 'Popis:',
'info_description' => 'Popis:',
'info_description_2' => 'Popis:',
'info_dimension' => 'Velikost:',
'info_document' => 'Dokument',
'info_document_indisponible' => 'This document is unavailable', # NEW
'info_documents' => 'Dokumenty',
'info_documents_nb' => '@nb@ documents', # NEW
'info_documents_un' => '1 document', # NEW
'info_echange_message' => 'Syst&eacute;m SPIP umo&#382;&#328;uje v&yacute;m&#283;nu zpr&aacute;v a vytv&aacute;&#345;en&iacute; soukrom&yacute;ch
  diskusn&iacute;ch skupin pro &uacute;&#269;astn&iacute;ky webu. Tuto funkci m&#367;&#382;ete
  zapnout nebo vypnout.',
'info_ecire_message_prive' => 'Napsat soukromou zpr&aacute;vu',
'info_email_invalide' => 'Neplatn&yacute; e-mail.',
'info_en_cours_validation' => 'Va&#353;e rozpracovan&eacute; &#269;l&aacute;nky',
'info_en_ligne' => 'Nyn&iacute; online:',
'info_envoyer_message_prive' => 'Odeslat soukromou zpr&aacute;vu tomuto autorovi',
'info_erreur_requete' => 'Chyba p&#345;i datab&aacute;zov&eacute;m dotazu:',
'info_erreur_squelette2' => 'Neexistuj&iacute;c&iacute; &#353;ablona <b>@fichier@</b>...',
'info_erreur_systeme' => 'Syst&eacute;mov&aacute; chyba (&#269;&iacute;slo: @errsys@)',
'info_erreur_systeme2' => 'Pevn&yacute; disk m&#367;&#382;e b&yacute;t pln&yacute; nebo m&#367;&#382;e b&yacute;t po&#353;kozen. <br />
 <font color=\'red\'>Zkuste <a href=\'@script@\'>opravit datab&aacute;zi</a>,
 nebo kontaktujte sv&eacute;ho poskytovatele prostoru pro web.</font>', # MODIF
'info_fini' => 'Hotovo!',
'info_format_image' => 'Form&aacute;t obr&aacute;zku pro tvorbu n&aacute;hled&#367;: @gd_formats@.',
'info_format_non_defini' => 'form&aacute;t nen&iacute; definov&aacute;n',
'info_grand_ecran' => 'Velk&eacute; zobrazen&iacute;',
'info_image_aide' => 'N&Aacute;POV&#282;DA',
'info_image_process_titre' => 'N&aacute;vod k vytvo&#345;en&iacute; n&aacute;hled&#367;',
'info_impossible_lire_page' => '<b>Chyba!</b> Str&aacute;nku nelze &#269;&iacute;st <tt><html>@test_proxy@</html></tt> p&#345;es proxy br&aacute;nu <tt>', # MODIF
'info_inclusion_directe' => 'P&#345;&iacute;m&eacute; vlo&#382;en&iacute;:',
'info_inclusion_vignette' => 'Vlo&#382;it n&aacute;hled:',
'info_installation_systeme_publication' => 'Instalace publika&#269;n&iacute;ho syst&eacute;mu ...',
'info_installer_documents' => 'V&#353;echny dokumenty ve slo&#382;ce @upload@ lze nainstalovat automaticky.',
'info_installer_ftp' => 'Jako spr&aacute;vce m&#367;&#382;ete instalovat (pomoc&iacute; FTP) soubory do slo&#382;ky @upload@ a n&aacute;sledn&#283; je odtamtud m&#367;&#382;ete p&#345;&iacute;mo vyb&iacute;rat.',
'info_installer_images' => 'Obr&aacute;zky lze instalovat ve form&aacute;tu JPEG, GIF a PNG.',
'info_installer_images_dossier' => 'Nainstalujte obr&aacute;zky do slo&#382;ky @upload@, abyste je odtamtud mohli vyb&iacute;rat.',
'info_installer_tous_documents' => 'Instalovat v&#353;echny dokumenty',
'info_interface_complete' => '&uacute;pln&eacute; rozhran&iacute;',
'info_interface_simple' => 'jednoduch&eacute; rozhran&iacute;',
'info_joindre_document_article' => 'K &#269;l&aacute;nku lze p&#345;ipojit dokumenty ve form&aacute;tu',
'info_joindre_document_rubrique' => 'K t&eacute;to sekci m&#367;&#382;ete p&#345;id&aacute;vat dokumenty ve form&aacute;tu',
'info_joindre_documents_article' => 'K &#269;l&aacute;nku m&#367;&#382;ete p&#345;id&aacute;vat dokumenty ve form&aacute;tu:',
'info_l_article' => '&#269;l&aacute;nek',
'info_la_breve' => 'novinka',
'info_la_rubrique' => 'sekce',
'info_langue_principale' => 'Hlavn&iacute; jazyk str&aacute;nek',
'info_largeur_vignette' => '@largeur_vignette@ &times; @hauteur_vignette@ pixel&#367;',
'info_les_auteurs_1' => 'od @les_auteurs@',
'info_logo_format_interdit' => 'Loga jsou povolena pouze ve form&aacute;tu @formats@.',
'info_logo_max_poids' => 'Log nesm&iacute; b&yacute;t v&#283;t&#353;&iacute; ne&#382; @maxi@ (tento soubor m&aacute; velikost @actuel@).',
'info_logo_max_taille' => 'Logo nesm&iacute; b&yacute;t v&#283;t&#353;&iacute; ne&#382; @maxi@ (tento soubor m&aacute; velikost @actuel@).',
'info_mail_fournisseur' => 'you@isp.com',
'info_message_2' => 'ZPR&Aacute;VA',
'info_message_supprime' => 'ZPR&Aacute;VA BYLA ODSTRAN&#282;NA',
'info_messages_nb' => '@nb@ messages', # NEW
'info_messages_un' => '1 message', # NEW
'info_mise_en_ligne' => 'Datum zve&#345;ejn&#283;n&iacute; online:',
'info_modification_parametres_securite' => '&uacute;prava bezpe&#269;nostn&iacute;ch parametr&#367;',
'info_mois_courant' => 'V m&#283;s&iacute;ci:',
'info_mot_cle_ajoute' => 'Bylo p&#345;id&aacute;no toto kl&iacute;&#269;ov&eacute; slovo',
'info_multi_herit' => 'V&yacute;choz&iacute; jazyk',
'info_multi_langues_soulignees' => 'Jazyky <u>zobrazen&eacute; podtr&#382;en&#283;</u> maj&iacute; p&#345;elo&#382;eno cel&eacute; rozhran&iacute;. Pokue je zvol&iacute;te, bude automaticky p&#345;elo&#382;ena cel&aacute; &#345;ada polo&#382;ek ve&#345;ejn&yacute;ch str&aacute;neki(data, formul&aacute;&#345;e). U jazyk&#367;, kter&eacute; nejsou podtr&#382;eny, budou tyto polo&#382;ky zobrazeny v hlavn&iacute;m jazyce str&aacute;nek.', # MODIF
'info_multilinguisme' => 'V&iacute;cejazy&#269;n&eacute;',
'info_nom_non_utilisateurs_connectes' => 'Va&#353;e jm&eacute;no nen&iacute; uvedeno na seznamu p&#345;ipojen&yacute;ch u&#382;ivatel&#367;.',
'info_nom_utilisateurs_connectes' => 'Va&#353;e jm&eacute;no je uvedeno na seznamu p&#345;ipojen&yacute;ch u&#382;ivatel&#367;.',
'info_nombre_en_ligne' => 'Aktu&aacute;ln&#283; online:',
'info_non_resultat' => '&#377;&aacute;dn&eacute; v&yacute;sledky pro "@cherche_mot@"',
'info_non_utilisation_messagerie' => 'Nepou&#382;&iacute;v&aacute;te syst&eacute;m pro intern&iacute; zas&iacute;l&aacute;n&iacute; zpr&aacute;v v r&aacute;mci t&#283;chto str&aacute;nek.',
'info_nouveau_message' => 'M&Aacute;TE NOVOU ZPR&Aacute;VU',
'info_nouveaux_messages' => 'M&Aacute;TE CELKEM @total_messages@ NOV&Yacute;CH ZPR&Aacute;V',
'info_numero_abbreviation' => '&#269;.',
'info_obligatoire' => 'This information is required', # NEW
'info_panne_site_syndique' => 'Syndikovan&yacute; web nefunguje',
'info_pense_bete' => 'POZN&Aacute;MKA',
'info_petit_ecran' => 'Mal&yacute; displej',
'info_petition_close' => 'Petition closed', # NEW
'info_pixels' => 'pixel&#367;',
'info_plusieurs_mots_trouves' => 'Pro "@cherche_mot@" bylo nalezeno n&#283;kolik kl&iacute;&#269;ov&yacute;ch slov:',
'info_popularite_5' => 'obl&iacute;benost:',
'info_portfolio' => 'Portfolio',
'info_portfolio_automatique' => 'Automatizovan&eacute; portfolio:',
'info_premier_resultat' => '[@debut_limit@ prvn&iacute;ch v&yacute;sledk&#367; z @total@]',
'info_premier_resultat_sur' => '[@debut_limit@ prvn&iacute;ch v&yacute;sledk&#367; z @total@]',
'info_probleme_grave' => 'chyba',
'info_propose_1' => '[@nom_site_spip@] P&#345;edlo&#382;eno: @titre@',
'info_propose_2' => 'P&#345;edlo&#382;en &#269;l&aacute;nek
-----------------',
'info_propose_3' => '&#268;l&aacute;nek "@titre@" byl p&#345;edlo&#382;en ke zve&#345;ejn&#283;n&iacute;.',
'info_propose_4' => 'Pros&iacute;m, p&#345;e&#269;t&#283;te si jej a sd&#283;lte sv&#367;j n&aacute;zor',
'info_propose_5' => 'v diskusn&iacute; skupin&#283;, na n&iacute;&#382; navazuje. Je k dispozici na adrese:',
'info_publie_01' => '&#268;l&aacute;nek "@titre@" byl schv&aacute;len @connect_nom@.',
'info_publie_1' => '[@nom_site_spip@] ZVE&#344;EJN&#282;NO: @titre@',
'info_publie_2' => 'Zve&#345;ejn&#283;n&yacute; &#269;l&aacute;nek
-----------------',
'info_rechercher' => 'Naj&iacute;t',
'info_rechercher_02' => 'Naj&iacute;t:',
'info_remplacer_vignette' => 'Nahradit standardn&iacute; n&aacute;hled vlastn&iacute;m logem:',
'info_retablir_lien' => 'obnovit tento odkaz',
'info_retirer_mot' => 'Odstranit toto kl&iacute;&#269;ov&eacute; slovo',
'info_retirer_mots' => 'Odstranit v&#353;echna kl&iacute;&#269;ov&aacute; slova',
'info_rubriques_nb' => '@nb@ sections', # NEW
'info_rubriques_un' => '1 section', # NEW
'info_sans_titre_2' => 'bez n&aacute;zvu',
'info_selectionner_fichier' => 'M&#367;&#382;ete vybrat soubor ze slo&#382;ky @upload@',
'info_selectionner_fichier_2' => 'Vybrat soubor:',
'info_signature_supprimee' => 'Signature deleted', # NEW
'info_signature_supprimee_erreur' => 'Error: this deletion code does not correspond to any signature', # NEW
'info_site_attente' => 'Web &#269;ek&aacute; na schv&aacute;len&iacute;',
'info_site_reference' => 'Web odkazovan&yacute; online',
'info_site_refuse' => 'Web byl odm&iacute;tnut',
'info_sites_nb' => '@nb@ sites', # NEW
'info_sites_referencer' => 'Zadat odkaz na web',
'info_sites_un' => '1 site', # NEW
'info_supprimer_vignette' => 'odstranit n&aacute;hled',
'info_symbole_bleu' => '<b>Modr&yacute;m</b> symbolem je ozna&#269;ena <b>intern&iacute; pozn&aacute;mka</b>, tj. zpr&aacute;va ur&#269;en&aacute; pro osobn&iacute; pot&#345;ebu.', # MODIF
'info_symbole_jaune' => '<b>&#381;lut&yacute;m</b> symbolem je ozna&#269;ena <b>zpr&aacute;va pro v&#353;echny redaktory</b>: m&#367;&#382;e ji upravovat kter&yacute;koli ze spr&aacute;vc&#367; a zobrazuje se v&#353;em redaktor&#367;m.', # MODIF
'info_symbole_vert' => '<b>Zelen&yacute;m</b> symbolem jsou ozna&#269;eny <b>zpr&aacute;vy vym&#283;&#328;ovan&eacute; s ostatn&iacute;mi u&#382;ivateli</b> webu.', # MODIF
'info_syndication' => 'syndikace:',
'info_syndication_articles' => '&#269;l&aacute;nek/&#269;l&aacute;nk&#367;',
'info_telecharger' => 'Odeslat z po&#269;&iacute;ta&#269;e:',
'info_telecharger_nouveau_logo' => 'Odeslat nov&eacute; logo:',
'info_telecharger_ordinateur' => 'Odeslat z po&#269;&iacute;ta&#269;e:',
'info_tous_resultats_enregistres' => '[v&#353;echny v&yacute;sledky jsou zaps&aacute;ny]',
'info_tout_afficher' => 'Zobrazit v&#353;e',
'info_travaux_texte' => 'Tyto str&aacute;nky nejsou je&#353;t&#283; nastaveny. Nav&#353;tivte je, pros&iacute;m, pozd&#283;ji...',
'info_travaux_titre' => 'Na webu se pracuje',
'info_trop_resultat' => 'Pro: "@cherche_mot@" bylo zobrazeno p&#345;&iacute;li&#353; mnoho v&yacute;sledk&#367;. Zadejte podrobn&#283;j&#353;&iacute; krit&eacute;ria pro vyhled&aacute;v&aacute;n&iacute;.',
'info_utilisation_messagerie_interne' => 'U tohoto webu pou&#382;&iacute;v&aacute;te syst&eacute;m intern&iacute;ch zpr&aacute;v.',
'info_valider_lien' => 'schv&aacute;lit tento odkaz',
'info_verifier_image' => ', zkontrolujte, zda jste obr&aacute;zky p&#345;enesli spr&aacute;vn&#283;.',
'info_vignette_defaut' => 'V&yacute;choz&iacute; n&aacute;hled',
'info_vignette_personnalisee' => 'Vlastn&iacute; n&aacute;hled',
'info_visite' => 'n&aacute;v&#353;t&#283;vy:',
'info_visites' => 'n&aacute;v&#353;t&#283;vy:',
'info_vos_rendez_vous' => 'Va&#353;e budouc&iacute; sch&#367;zky',
'info_zoom' => 'zv&#283;t&#353;it/zmen&#353;it',
'infos_vos_pense_bete' => 'Va&#353;e pozn&aacute;mky', # MODIF
'item_breve_proposee' => 'P&#345;edlo&#382;en&eacute; novinky',

// L
'lien_afficher_icones_seuls' => 'Zobrazit pouze ikony',
'lien_afficher_texte_icones' => 'Zobrazit ikony a text',
'lien_afficher_texte_seul' => 'Zobrazit pouze text',
'lien_liberer' => 'verze',
'lien_liberer_tous' => 'uvolnit tyto &#269;l&aacute;nky',
'lien_nouvea_pense_bete' => 'NOV&Aacute; POZN&Aacute;MKA',
'lien_nouveau_message' => 'NOV&Aacute; ZPR&Aacute;VA',
'lien_nouvelle_annonce' => 'NOV&Eacute; OZN&Aacute;MEN&Iacute;',
'lien_petitions' => 'PETICE',
'lien_popularite' => 'obl&iacute;benost: @popularite@%',
'lien_racine_site' => 'KO&#344;ENOV&Yacute; ADRES&Aacute;&#344; STR&Aacute;NEK',
'lien_reessayer' => 'zkusit znovu',
'lien_repondre_message' => 'Odpov&#283;d&#283;t na zpr&aacute;vu',
'lien_supprimer' => 'odstranit',
'lien_tout_afficher' => 'Zobrazit v&#353;e',
'lien_visite_site' => 'nav&#353;t&iacute;vit tyto str&aacute;nky',
'lien_visites' => '@visites@ n&aacute;v&#353;t&#283;v',
'lien_voir_auteur' => 'Zobrazit autora',
'ligne' => 'Line', # NEW
'login' => 'Connection', # NEW
'login_acces_prive' => 'p&#345;&iacute;stup do neve&#345;ejn&eacute; oblasti',
'login_autre_identifiant' => 'pou&#382;&iacute;t jin&eacute; ID',
'login_cookie_accepte' => 'Nastavte prohl&iacute;&#382;e&#269; tak, aby je p&#345;ij&iacute;mal (alespo&#328; pro tento web).',
'login_cookie_oblige' => 'Pro bezpe&#269;nou identifikaci mus&iacute; b&yacute;t povoleny soubory cookies.',
'login_deconnexion_ok' => 'Byli jste odhl&aacute;&#353;eni.',
'login_erreur_pass' => 'Nespr&aacute;vn&eacute; heslo.',
'login_espace_prive' => 'neve&#345;ejn&aacute; oblast',
'login_identifiant_inconnu' => 'Identifikace "@login@" je nezn&aacute;m&aacute;.',
'login_login' => 'P&#345;ihl&aacute;&#353;en&iacute;:',
'login_login2' => 'P&#345;ihla&#353;ovac&iacute; &uacute;daje (identifikace pro p&#345;ipojen&iacute; k t&#283;mto str&aacute;nk&aacute;m):',
'login_login_pass_incorrect' => '(Nespr&aacute;vn&eacute; u&#382;ivatelsk&eacute; jm&eacute;no nebo heslo).',
'login_motpasseoublie' => 'zapomn&#283;li jste heslo?',
'login_non_securise' => 'POZOR! Tento formul&aacute;&#345; nen&iacute; zabezpe&#269;en&yacute;.
   Pokud nechcete, aby va&#353;e heslo mohl n&#283;kdo
   b&#283;hem p&#345;enosu po s&iacute;ti zachytit, zapn&#283;te v prohl&iacute;&#382;e&#269;i
   Javascript a',
'login_nouvelle_tentative' => 'Dal&#353;&iacute; pokus',
'login_par_ici' => 'Jste registrov&aacute;ni... takto...',
'login_pass2' => 'Heslo:',
'login_preferez_refuser' => '<b>Nechcete-li soubory cookies povolit</b>, existuje i jin&yacute; (m&eacute;n&#283; bezpe&#269;n&yacute;) zp&#367;sob p&#345;ipojen&iacute;:',
'login_recharger' => 'znovu na&#269;&iacute;st tuto str&aacute;nku',
'login_rester_identifie' => 'Pamatovat moje ID n&#283;kolik dn&iacute;',
'login_retour_public' => 'Zp&#283;t na ve&#345;ejn&eacute; str&aacute;nky',
'login_retour_site' => 'Zp&#283;t na ve&#345;ejn&eacute; str&aacute;nky',
'login_retoursitepublic' => 'zp&#283;t na ve&#345;ejn&eacute; str&aacute;nky',
'login_sans_cookiie' => 'Identifikace bez pou&#382;it&iacute; cookies',
'login_securise' => 'Secured login', # NEW
'login_sinscrire' => 'registrovat',
'login_test_navigateur' => 'test prohl&iacute;&#382;e&#269;e/opakovan&eacute; p&#345;ipojen&iacute;',
'login_verifiez_navigateur' => '(P&#345;esv&#283;d&#269;te se v&#353;ak, zda si prohl&iacute;&#382;e&#269; nezapamatoval va&#353;e heslo...)',

// M
'masquer_colonne' => 'Hide this column', # NEW
'masquer_trad' => 'skr&yacute;t p&#345;eklady',
'module_fichiers_langues' => 'Jazykov&eacute; soubory',

// N
'navigateur_pas_redirige' => 'Nedojde-li k p&#345;esm&#283;rov&aacute;n&iacute; prohl&iacute;&#382;e&#269;e, klepn&#283;te sem.',
'numero' => 'Number', # NEW

// O
'occurence' => 'Instance', # NEW
'onglet_affacer_base' => 'Odstranit datab&aacute;zi',
'onglet_auteur' => 'Autor',
'onglet_contenu_site' => 'Obsah webu',
'onglet_evolution_visite_mod' => '&Uacute;rove&#328; n&aacute;v&#353;t&#283;v',
'onglet_fonctions_avances' => 'Roz&#353;&iacute;&#345;en&eacute; funkce',
'onglet_informations_personnelles' => 'Osobn&iacute; &uacute;daje',
'onglet_interactivite' => 'Interaktivita',
'onglet_messagerie' => 'Syst&eacute;m zpr&aacute;v',
'onglet_messages_internes' => 'Intern&iacute; zpr&aacute;vy',
'onglet_messages_publics' => 'Ve&#345;ejn&eacute; zpr&aacute;vy',
'onglet_messages_vide' => 'Zpr&aacute;vy bez textu',
'onglet_origine_visites' => 'P&#367;vod n&aacute;v&#353;t&#283;v',
'onglet_repartition_debut' => 'od po&#269;&aacute;tku',
'onglet_repartition_lang' => 'Rozd&#283;len&iacute; podle jazyk&#367;',
'onglet_repartition_rubrique' => 'Rozd&#283;len&iacute; podle sekc&iacute;',
'onglet_save_restaur_base' => 'Z&aacute;loha/obnova datab&aacute;ze',
'onglet_vider_cache' => 'Vymazat mezipam&#283;t (cache)',

// P
'pass_choix_pass' => 'Zadejte nov&eacute; heslo:',
'pass_erreur' => 'Chyba',
'pass_erreur_acces_refuse' => '<b>Chyba:</b> K t&#283;mto str&aacute;nk&aacute;m ji&#382; nem&aacute;te p&#345;&iacute;stup.',
'pass_erreur_code_inconnu' => '<b>Chyba:</b> Zadan&eacute; k&oacute;dy neodpov&iacute;daj&iacute; &#382;&aacute;dn&eacute;mu n&aacute;v&#353;t&#283;vn&iacute;kovi, kter&yacute; m&aacute; k t&#283;mto str&aacute;nk&aacute;m p&#345;&iacute;stup.',
'pass_erreur_non_enregistre' => '<b>Chyba:</b> Adresa <tt>@email_oubli@</tt> nen&iacute; na t&#283;chto str&aacute;nk&aacute;ch zaregistrov&aacute;na.',
'pass_erreur_non_valide' => '<b>Chyba:</b> Neplatn&yacute; e-mail <tt>@email_oubli@</tt>!',
'pass_erreur_probleme_technique' => '<b>Chyba:</b> Z technick&yacute;ch d&#367;vod&#367; nebylo mo&#382;n&eacute; e-mail odeslat.',
'pass_espace_prive_bla' => 'Neve&#345;ejn&aacute; oblast str&aacute;nek je n&aacute;v&#353;t&#283;vn&iacute;k&#367;m
p&#345;&iacute;stupn&aacute; po registraci. Jakmile se zaregistrujete,
budete moci korigovat rozpracovan&eacute; &#269;l&aacute;nky,
p&#345;edkl&aacute;dat &#269;l&aacute;nky ke schv&aacute;len&iacute; a budete se moci &uacute;&#269;astnit diskusn&iacute;ch skupin.',
'pass_forum_bla' => 'Po&#382;&aacute;dali jste o &uacute;&#269;ast v diskusn&iacute; skupin&#283;,
kter&aacute; je vyhrazena registrovan&yacute;m u&#382;ivatel&#367;m.',
'pass_indiquez_cidessous' => 'D&aacute;le zadejte elektronickou adresu, pod kterou
jste ji&#382; zaregistrov&aacute;ni. Obdr&#382;&iacute;te
e-mail, kde bude vysv&#283;tleno, jak
z&iacute;sk&aacute;te p&#345;&iacute;stup zp&#283;t.',
'pass_mail_passcookie' => '(toto je automatick&aacute; zpr&aacute;va)
P&#345;&iacute;stup ke str&aacute;nk&aacute;m
@nom_site_spip@ (@adresse_site@)

z&iacute;sk&aacute;te p&#345;echodem na adresu:

    @sendcookie@

Tam zad&aacute;te nov&eacute; heslo
a znovu se ke str&aacute;nk&aacute;m p&#345;ipoj&iacute;te.

',
'pass_mot_oublie' => 'Zapomenut&eacute; heslo',
'pass_nouveau_enregistre' => 'Nov&eacute; heslo bylo zaps&aacute;no.',
'pass_nouveau_pass' => 'Nov&eacute; heslo',
'pass_ok' => 'V po&#345;&aacute;dku',
'pass_oubli_mot' => 'Zapomenut&eacute; heslo',
'pass_quitter_fenetre' => 'Odej&iacute;t z tohoto okna',
'pass_rappel_login' => 'P&#345;ipomenut&iacute;: Va&#353;e u&#382;ivatelsk&eacute; jm&eacute;no (login) je "@login@".',
'pass_recevoir_mail' => 'Obdr&#382;&iacute;te e-mail s vysv&#283;tlen&iacute;m, jak znovu z&iacute;skat p&#345;&iacute;stup k t&#283;mto str&aacute;nk&aacute;m.',
'pass_retour_public' => 'Zp&#283;t na ve&#345;ejn&#283; p&#345;&iacute;stupn&eacute; str&aacute;nky',
'pass_rien_a_faire_ici' => 'Tady nen&iacute; co d&#283;lat :-).',
'pass_vousinscrire' => 'Registrace p&#345;&iacute;stupu na str&aacute;nky',
'precedent' => 'p&#345;edchoz&iacute;',
'previsualisation' => 'N&aacute;hled',
'previsualiser' => 'N&aacute;hled',

// R
'retour' => 'Return', # NEW

// S
'spip_conforme_dtd' => 'SPIP finds this page to be in compliance with its DOCTYPE:', # NEW
'squelette' => '&#353;ablona',
'squelette_inclus_ligne' => 'vlo&#382;en&aacute; &#353;ablona, &#345;&aacute;dek',
'squelette_ligne' => '&#353;ablona, &#345;&aacute;dek',
'stats_visites_et_popularite' => 'po&#269;et n&aacute;v&#353;t&#283;v: @visites@; obl&iacute;benost: @popularite@',
'suivant' => 'dal&#353;&iacute;',

// T
'taille_ko' => '@taille@&nbsp;kb',
'taille_mo' => '@taille@&nbsp;Mb',
'taille_octets' => '@taille@&nbsp;byt&#367;',
'texte_actualite_site_1' => 'A&#382; se s rozhran&iacute;m obezn&aacute;m&iacute;te, klepn&#283;te na "',
'texte_actualite_site_2' => '&uacute;pln&eacute; rozhran&iacute;',
'texte_actualite_site_3' => '&raquo; ke zp&#345;&iacute;stupn&#283;n&iacute; v&iacute;ce funkc&iacute;.',
'texte_creation_automatique_vignette' => 'Na t&#283;chto str&aacute;nk&aacute;ch je zapnuta automatick&aacute; tvorba n&aacute;hled&#367; a jejich p&#345;edb&#283;&#382;n&eacute; zobrazen&iacute;. Pokud pomoc&iacute; tohoto formul&aacute;&#345;e nainstalujete obr&aacute;zky ve form&aacute;tu @gd_formats@, budou spojeny s n&aacute;hledem, kter&yacute; m&aacute; maxim&aacute;ln&iacute; velikost @taille_preview@ pixel&#367;.',
'texte_documents_associes' => 'S &#269;l&aacute;nkem jsou spojeny n&aacute;sleduj&iacute;c&iacute; dokumenty,
    je&#382; v&#353;ak do n&#283;j nejsou p&#345;&iacute;mo
    vlo&#382;eny. Podle ve&#345;ejn&eacute;ho vzhledu str&aacute;nek
    se mohou zobrazit jako p&#345;ilo&#382;en&eacute; dokumenty.',
'texte_erreur_mise_niveau_base' => 'P&#345;i aktualizaci datab&aacute;ze do&#353;lo k chyb&#283;.
      Obr&aacute;zek <b>@fichier@</b> nebylo mo&#382;n&eacute; p&#345;edat (&#269;l&aacute;nek @id_article@).<p>
      Pe&#269;liv&#283; si poznamenejte toto &#269;&iacute;slo, zkuste aktualizaci
      a p&#345;esv&#283;d&#269;te se, &#382;e obr&aacute;zky jsou i nad&aacute;le v &#269;l&aacute;nc&iacute;ch
      zobrazeny.', # MODIF
'texte_erreur_visiteur' => 'You have tried to enter the private area using a login which does not permit this.', # NEW
'texte_inc_auth_1' => 'P&#345;ihl&aacute;sili jsgte se jako
  <b>@auth_login@</b>, ale toto u&#382;ivatelsk&eacute; jm&eacute;no (ji&#382;) v datab&aacute;zi neexistuje. 
  Zkuste', # MODIF
'texte_inc_auth_2' => 'znovu p&#345;ipojit',
'texte_inc_auth_3' => 'po opu&#353;t&#283;n&iacute;
  restartujte v p&#345;&iacute;pad&#283; pot&#345;eby prohl&iacute;&#382;e&#269;.',
'texte_inc_config' => 'N&iacute;&#382;e uveden&eacute; &uacute;pravy v&yacute;znamn&#283; ovliv&#328;uj&iacute;
  fungov&aacute;n&iacute; webu. M&#283;nit tato nastaven&iacute; by m&#283;li jenom u&#382;ivatel&eacute;, kte&#345;&iacute; dob&#345;e v&#283;d&iacute;,
 jak syst&eacute;m SPIP funguje. <br /><br /><b>Obecn&#283;
 plat&iacute;, &#382;e s t&#283;mito str&aacute;nkami by m&#283;l pracovat pouze hlavn&iacute; spr&aacute;vce va&#353;eho webu.</b>', # MODIF
'texte_inc_meta_1' => 'P&#345;i pokusu o z&aacute;pis do souboru  <code>@fichier@</code> do&#353;lo k syst&eacute;mov&eacute; chyb&#283;. Jako&#382;to spr&aacute;vce webu',
'texte_inc_meta_2' => 'zkontrolujte opr&aacute;vn&#283;n&iacute; k z&aacute;pisu ',
'texte_inc_meta_3' => 'do adres&aacute;&#345;e <code>@repertoire@</code>.',
'texte_statut_en_cours_redaction' => 'rozpracovan&eacute; &uacute;pravy',
'texte_statut_poubelle' => 'v ko&#353;i',
'texte_statut_propose_evaluation' => 'p&#345;edlo&#382;eno ke schv&aacute;len&iacute;',
'texte_statut_publie' => 'zve&#345;ejn&#283;no online',
'texte_statut_refuse' => 'odm&iacute;tnuto',
'titre_ajouter_mot_cle' => 'P&#344;IDAT KL&Iacute;&#268;OV&Eacute; SLOVO:',
'titre_breve_proposee' => 'P&#345;edlo&#382;en&aacute; novinka',
'titre_breve_publiee' => 'Novinka zve&#345;ejn&#283;na',
'titre_breve_refusee' => 'Novinka zam&iacute;tnuta',
'titre_cadre_raccourcis' => 'KL&Aacute;VESOV&Eacute; ZKRATKY:',
'titre_changer_couleur_interface' => 'Zm&#283;na barvy rozhran&iacute;',
'titre_forum' => 'Diskusn&iacute; skupina',
'titre_image_admin_article' => 'M&aacute;te mo&#382;nost spr&aacute;vy tohoto &#269;l&aacute;nku',
'titre_image_administrateur' => 'Spr&aacute;vce',
'titre_image_aide' => 'N&aacute;pov&#283;da k polo&#382;ce',
'titre_image_auteur_supprime' => 'Autor odstran&#283;n',
'titre_image_redacteur' => 'Redaktor bez p&#345;&iacute;stupu',
'titre_image_redacteur_02' => 'Redaktor',
'titre_image_visiteur' => 'N&aacute;v&#353;t&#283;vn&iacute;k',
'titre_joindre_document' => 'P&#344;IPOJIT DOKUMENT',
'titre_liens_entrants' => 'P&#345;&iacute;choz&iacute; odkazy',
'titre_mots_cles' => 'KL&Iacute;&#268;OV&Aacute; SLOVA',
'titre_probleme_technique' => 'Varov&aacute;n&iacute;: Z technick&yacute;ch d&#367;vod&#367; (server SQL) je tato &#269;&aacute;st webu nep&#345;&iacute;stupn&aacute;.<p>D&#283;kujeme v&aacute;m za pochopen&iacute;.', # MODIF
'titre_publier_document' => 'ZVE&#344;EJNIT DOKUMENT V T&Eacute;TO &#268;&Aacute;STI',
'titre_signatures_attente' => 'Signatures awaiting validation', # NEW
'titre_signatures_confirmees' => 'Confirmed signatures', # NEW
'titre_statistiques' => 'Statistiky str&aacute;nek',
'titre_titre_document' => 'N&aacute;zev dokumentu:',
'todo' => 'to come', # NEW
'trad_reference' => '(referen&#269;n&iacute; &#269;l&aacute;nek)',

// Z
'zbug_balise_b_aval' => ': tag B je p&#345;&iacute;li&#353; pozd&#283; ve smy&#269;ce',
'zbug_balise_inexistante' => 'error @from@: the #@balise@ tag does not exist', # MODIF
'zbug_balise_sans_argument' => 'Missing argument in the @balise@ tag', # NEW
'zbug_boucle' => 'smy&#269;ka',
'zbug_boucle_recursive_undef' => 'nedefinovan&aacute; rekurzivn&iacute; smy&#269;ka', # MODIF
'zbug_calcul' => 'calculation', # NEW
'zbug_champ_hors_boucle' => 'Pole @champ@ je mimo smy&#269;ku',
'zbug_champ_hors_motif' => 'Pole @champ@ je mimo smy&#269;ku a m&aacute; tag @motif@', # MODIF
'zbug_code' => 'k&oacute;d',
'zbug_critere_inconnu' => 'nezn&aacute;m&aacute; podm&iacute;nka @critere@', # MODIF
'zbug_distant_interdit' => 'extern&iacute; data jsou zak&aacute;z&aacute;na', # MODIF
'zbug_doublon_table_sans_cle_primaire' => 'doublons used on a table which does not have a simple primary key', # MODIF
'zbug_doublon_table_sans_index' => 'doubles in a table without an index', # MODIF
'zbug_erreur_boucle_double' => 'SMY&#268;KA@id@: dvoj&iacute; definice', # MODIF
'zbug_erreur_boucle_fermant' => 'SMY&#268;KA@id@: chyb&iacute; uzav&iacute;rac&iacute; tag', # MODIF
'zbug_erreur_boucle_syntaxe' => 'Nespr&aacute;vn&aacute; syntax (BOUCLE)', # MODIF
'zbug_erreur_compilation' => 'Compilation error', # NEW
'zbug_erreur_execution_page' => 'chyba p&#345;i v&yacute;po&#269;tu str&aacute;nky', # MODIF
'zbug_erreur_filtre' => 'Chyba - nedefinovan&yacute; filtr: <b>"@filtre@"</b>', # MODIF
'zbug_erreur_meme_parent' => '{meme_parent} t&yacute;k&aacute; se jenom smy&#269;ek (FORUMS) a (RUBRIQUES)', # MODIF
'zbug_erreur_squelette' => 'Chyba &#269;i chyby v &#353;ablon&#283;',
'zbug_hors_compilation' => 'Uncompiled', # NEW
'zbug_info_erreur_squelette' => 'Na webu do&#353;lo k chyb&#283;',
'zbug_inversion_ordre_inexistant' => 'obr&aacute;cen&eacute; nebo neexistuj&iacute;c&iacute; po&#345;ad&iacute;', # MODIF
'zbug_pagination_sans_critere' => '#PAGINATION tag without {pagination} criterion, or used in a recursive loop', # MODIF
'zbug_parametres_inclus_incorrects' => 'Nespr&aacute;vn&eacute; parametry inkluze', # MODIF
'zbug_profile' => 'Calculation time: @time@', # NEW
'zbug_resultat' => 'v&yacute;sledky',
'zbug_serveur_indefini' => 'Nedefinovan&yacute; server SQL', # MODIF
'zbug_statistiques' => 'SQL query statistics in order of duration', # NEW
'zbug_table_inconnue' => 'Nezn&aacute;m&aacute; tabulka SQL "@table@"',
'zxml_connus_attributs' => 'known attributes', # NEW
'zxml_de' => 'from', # NEW
'zxml_inconnu_attribut' => 'unknown attribute', # NEW
'zxml_inconnu_balise' => 'unknown tag', # NEW
'zxml_inconnu_entite' => 'unknown entity', # NEW
'zxml_inconnu_id' => 'unknown ID', # NEW
'zxml_mais_de' => 'but from', # NEW
'zxml_non_conforme' => 'not true to the principle', # NEW
'zxml_non_fils' => 'is not a child of', # NEW
'zxml_nonvide_balise' => 'tag not empty', # NEW
'zxml_obligatoire_attribut' => 'required attribute absent in', # NEW
'zxml_succession_fils_incorrecte' => 'incorrect child inheritance', # NEW
'zxml_survoler' => 'to see the correct ones, hover with the cursor', # NEW
'zxml_valeur_attribut' => 'attribute value', # NEW
'zxml_vide_balise' => 'empty tag', # NEW
'zxml_vu' => 'seen before', # NE
);

?>
